package api.txInfo

import android.content.ContentValues
import android.content.Context
import android.support.v7.widget.GridLayoutManager
import android.support.v7.widget.RecyclerView
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.*
import com.bumptech.glide.Glide

import com.idotools.sdk.gdt.R
import com.qq.e.ads.ContentAdType
import com.qq.e.ads.contentad.ContentAdData
import com.qq.e.ads.contentad.ContentData
import com.qq.e.ads.contentad.ContentType
import com.qq.e.ads.nativ.MediaListener
import com.qq.e.ads.nativ.MediaView
import com.qq.e.ads.nativ.NativeMediaADData
import com.qq.e.comm.constants.AdPatternType
import com.qq.e.comm.util.AdError


class LoadMoreAdapter(private val context: Context, private val mData: List<ContentAdData>, private val listener: OnItemClickListener) : RecyclerView.Adapter<RecyclerView.ViewHolder>() {

    // 普通布局
    val TYPE_ITEM = 1
    // 脚布局
    val TYPE_FOOTER = 2
    // 当前加载状态，默认为加载完成
    private var loadState = 2
    // 正在加载
    val LOADING = 1
    // 加载完成
    val LOADING_COMPLETE = 2
    // 加载到底
    val LOADING_END = 3

    interface OnItemClickListener {
        fun onItemClick()
    }


    override fun getItemViewType(position: Int): Int {
        // 最后一个item设置为FooterView
        return if (position + 1 == itemCount) {
            TYPE_FOOTER
        } else {
            TYPE_ITEM
        }
    }

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): RecyclerView.ViewHolder {
        // 通过判断显示类型，来创建不同的View
        return if (viewType == TYPE_ITEM) {
            val view = LayoutInflater.from(parent.context).inflate(R.layout.info_item, parent, false)
            RecyclerViewHolder(view)
        } else {
            val view = LayoutInflater.from(parent.context).inflate(R.layout.refresh_footer, parent, false)
            FootViewHolder(view)
        }
    }

    override fun onBindViewHolder(holder: RecyclerView.ViewHolder, position: Int) {
        if (holder is RecyclerViewHolder) {
            val contentAdData = mData!![position]
            if (contentAdData.type == ContentAdType.AD) {
                val nativeADDataRef = contentAdData as NativeMediaADData
                Glide.with(context).load(nativeADDataRef.iconUrl).into(holder.imgLogo!!)
                holder.textName!!.text = nativeADDataRef.title
                holder.textFrom!!.text = "广告"
                holder.mediaView!!.visibility = View.GONE
                holder.imgSize!!.visibility = View.GONE
                if (nativeADDataRef.adPatternType == AdPatternType.NATIVE_VIDEO && nativeADDataRef.isVideoLoaded) {
                    if (nativeADDataRef.isPlaying) {
                        holder.mediaView!!.visibility = View.VISIBLE
                    } else {
                        holder.mediaView!!.visibility = View.VISIBLE
                        nativeADDataRef.bindView(holder.mediaView, true) // 只有将MediaView和广告实例绑定之后，才能播放视频
                        nativeADDataRef.play()
                        /** 设置视频播放过程中的监听器  */
                        nativeADDataRef.setMediaListener(object : MediaListener {

                            /**
                             * 视频播放器初始化完成，准备好可以播放了
                             *
                             * @param videoDuration 视频素材的总时长
                             */
                            override fun onVideoReady(videoDuration: Long) {
                                Log.i(ContentValues.TAG, "onVideoReady, videoDuration = $videoDuration")
                            }

                            /** 视频开始播放  */
                            override fun onVideoStart() {
                                Log.i(ContentValues.TAG, "onVideoStart")
                            }

                            /** 视频暂停  */
                            override fun onVideoPause() {
                                Log.i(ContentValues.TAG, "onVideoPause")
                            }

                            /** 视频自动播放结束，到达最后一帧  */
                            override fun onVideoComplete() {
                                Log.i(ContentValues.TAG, "onVideoComplete")
                            }

                            /** 视频播放时出现错误  */
                            override fun onVideoError(error: AdError) {
                                Log.i(ContentValues.TAG, "onVideoError, errorCode: " + error.errorCode)
                            }

                            /** SDK内置的播放器控制条中的重播按钮被点击  */
                            override fun onReplayButtonClicked() {
                                Log.i(ContentValues.TAG, "onReplayButtonClicked")
                            }

                            /**
                             * SDK内置的播放器控制条中的下载/查看详情按钮被点击 注意:
                             * 这里是指UI中的按钮被点击了，而广告的点击事件回调是在onADClicked中，开发者如需统计点击只需要在onADClicked回调中进行一次统计即可。
                             */
                            override fun onADButtonClicked() {
                                Log.i(ContentValues.TAG, "onADButtonClicked")
                            }

                            /** SDK内置的全屏和非全屏切换回调，进入全屏时inFullScreen为true，退出全屏时inFullScreen为false  */
                            override fun onFullScreenChanged(inFullScreen: Boolean) {
                                Log.i(ContentValues.TAG, "onFullScreenChanged, inFullScreen = $inFullScreen")
                                // 原生视频广告默认静音播放，进入到全屏后建议开发者可以设置为有声播放
                                if (inFullScreen) {
                                    nativeADDataRef.setVolumeOn(true)
                                } else {
                                    nativeADDataRef.setVolumeOn(false)
                                }
                            }
                        })
                    }
                }
                val v = holder.itemView.findViewById(R.id.ad_info) as RelativeLayout
                nativeADDataRef.onExposured(v) // 需要先调用曝光接口
                v.setOnClickListener {
                    listener!!.onItemClick()
                    nativeADDataRef.onClicked(it)
                }
            } else if (contentAdData.type == ContentAdType.INFORMATION) {
                val contentData = contentAdData as ContentData
                if (contentData.images.size > 0) {
                    Glide.with(context).load(contentData.images[0]).into(holder.imgLogo!!)
                    holder.imgSize!!.visibility = View.VISIBLE
                    holder.imgSize!!.text = contentData.images.size.toString() + "图"
                } else {
                    holder.imgSize!!.visibility = View.GONE
                }
                holder.textName!!.text = contentData.title
                if (contentData.contentType == ContentType.ARTICLE) {
                    holder.textFrom!!.text = contentData.from
                    holder.texTime!!.text = contentData.elapseTime
                } else if (contentData.contentType == ContentType.VIDEO) {
                    holder.textFrom!!.text = contentData.from + "   " + contentData.label
                }
                val v = holder.itemView.findViewById(R.id.contentContainer) as LinearLayout
                contentData.onExpouse(v) // 需要先调用曝光接口
                v.setOnClickListener {
                    listener!!.onItemClick()
                    contentData.onClick(it)
                }
            }
            holder.itemView.tag = holder
        } else if (holder is FootViewHolder) {
            when (loadState) {
                LOADING // 正在加载
                -> {
                    holder.pbLoading.visibility = View.VISIBLE
                    holder.tvLoading.visibility = View.VISIBLE
                    holder.llEnd.visibility = View.GONE
                }
                LOADING_COMPLETE // 加载完成
                -> {
                    holder.pbLoading.visibility = View.INVISIBLE
                    holder.tvLoading.visibility = View.INVISIBLE
                    holder.llEnd.visibility = View.GONE
                }

                LOADING_END // 加载到底
                -> {
                    holder.pbLoading.visibility = View.GONE
                    holder.tvLoading.visibility = View.GONE
                    holder.llEnd.visibility = View.VISIBLE
                }
            }
        }
    }

    override fun getItemCount(): Int {
        return if (mData.isNotEmpty()) {
            mData.size + 1
        } else {
            0
        }
    }

    override fun onAttachedToRecyclerView(recyclerView: RecyclerView) {
        super.onAttachedToRecyclerView(recyclerView)
        val manager = recyclerView.layoutManager
        if (manager is GridLayoutManager) {
            val gridManager = manager as GridLayoutManager?
            gridManager!!.spanSizeLookup = object : GridLayoutManager.SpanSizeLookup() {
                override fun getSpanSize(position: Int): Int {
                    // 如果当前是footer的位置，那么该item占据2个单元格，正常情况下占据1个单元格
                    return if (getItemViewType(position) == TYPE_FOOTER) gridManager.spanCount else 1
                }
            }
        }
    }

    inner class RecyclerViewHolder(itemView: View) : RecyclerView.ViewHolder(itemView) {
        val mediaView = itemView!!.findViewById(R.id.media_view) as MediaView
        val imgLogo = itemView.findViewById(R.id.img) as ImageView
        val textName = itemView.findViewById(R.id.title) as TextView
        val textFrom = itemView.findViewById(R.id.from) as TextView
        val texTime = itemView.findViewById(R.id.time) as TextView
        val imgSize = itemView.findViewById(R.id.imgSize) as TextView

    }

    inner class FootViewHolder(itemView: View) : RecyclerView.ViewHolder(itemView) {
        val pbLoading: ProgressBar = itemView.findViewById<View>(R.id.pb_loading) as ProgressBar
        var tvLoading: TextView = itemView.findViewById<View>(R.id.tv_loading) as TextView
        var llEnd: LinearLayout = itemView.findViewById<View>(R.id.ll_end) as LinearLayout
    }

    /**
     * 设置上拉加载状态
     * @param  0.正在加载 1.加载完成 2.加载到底
     */
    fun setLoadState(loadState: Int) {
        this.loadState = loadState
        notifyDataSetChanged()
    }
}
